@@ -3,20 +3,23 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <config.h>
+#include <string.h>
 /* defines and includes common among the fsck.jfs modules */
 #include "xfsckint.h"
+#include "diskmap.h"
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
@@ -131,7 +134,7 @@ int ctlpage_rebuild(int8_t max_buddy)
 		    BMAPSZTOLEV(agg_recptr->sb_agg_fsblk_length);
 
 		/* check out the active AGs */
-		for (agidx = 0; (agidx < MAXAG); agidx++) {	
+		for (agidx = 0; (agidx < MAXAG); agidx++) {
 			if (bmap_recptr->AGActive[agidx]) {
 				highest_active_AG = agidx;
 				num_active_AGs++;
@@ -145,9 +148,9 @@ int ctlpage_rebuild(int8_t max_buddy)
 		actAG_free = bmap_recptr->free_blocks - inactAG_free;
 		avg_free = actAG_free / num_active_AGs;
 
-		if ((bmap_recptr->bmpctl_bufptr->dn_agpref > highest_active_AG) 
+		if ((bmap_recptr->bmpctl_bufptr->dn_agpref > highest_active_AG)
 		    || (bmap_recptr->bmpctl_bufptr->dn_agfree[bmap_recptr->
-		     bmpctl_bufptr->dn_agpref] < avg_free)) {	
+		     bmpctl_bufptr->dn_agpref] < avg_free)) {
 			/* preferred AG is not valid */
 			if (avg_free == 0) {
 				bmap_recptr->bmpctl_bufptr->dn_agpref = 0;
@@ -156,7 +159,7 @@ int ctlpage_rebuild(int8_t max_buddy)
 				for (agidx = 0; ((agidx < MAXAG) &&
 						 (bmap_recptr->bmpctl_bufptr->
 						  dn_agpref < 0)); agidx++) {
-					if (bmap_recptr->AGFree_tbl[agidx] >= 
+					if (bmap_recptr->AGFree_tbl[agidx] >=
 					    avg_free) {
 						bmap_recptr->bmpctl_bufptr->
 						    dn_agpref = agidx;
@@ -185,7 +188,7 @@ int ctlpage_rebuild(int8_t max_buddy)
 		bmap_recptr->bmpctl_bufptr->dn_agsize = sb_ptr->s_agsize;
 		bmap_recptr->bmpctl_bufptr->dn_maxfreebud = max_buddy;
 
-		for (agidx = 0; (agidx < MAXAG); agidx++) {	
+		for (agidx = 0; (agidx < MAXAG); agidx++) {
 			/* rebuild the free list */
 			bmap_recptr->bmpctl_bufptr->dn_agfree[agidx] =
 			    bmap_recptr->AGFree_tbl[agidx];
@@ -226,39 +229,39 @@ int ctlpage_verify(int8_t max_buddy)
 	bcv_rc = mapctl_get(bmap_recptr->bmpctl_agg_fsblk_offset,
 			    (void **) &(bmap_recptr->bmpctl_bufptr));
 
-	if (bcv_rc == FSCK_OK) {	
+	if (bcv_rc == FSCK_OK) {
 		/* got the control page in the buffer */
 
 		/* swap if on big endian machine */
 		ujfs_swap_dbmap((struct dbmap *) bmap_recptr->bmpctl_bufptr);
 
-		if (bmap_recptr->bmpctl_bufptr->dn_mapsize != bmap_recptr->total_blocks) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_mapsize != bmap_recptr->total_blocks) {
 			/* bad number of blocks in the aggregate */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCASB);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_nfree != bmap_recptr->free_blocks) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_nfree != bmap_recptr->free_blocks) {
 			/* bad number of free blocks in the aggregate */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCNF);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_l2nbperpage != agg_recptr->log2_blksperpg) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_l2nbperpage != agg_recptr->log2_blksperpg) {
 			/* bad log2( blocks per page ) */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCL2BPP);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_numag != agg_recptr->num_ag) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_numag != agg_recptr->num_ag) {
 			/* bad number of alloc groups */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCNAG);
 		}
 		max_level = BMAPSZTOLEV(agg_recptr->sb_agg_fsblk_length);
-		if (bmap_recptr->bmpctl_bufptr->dn_maxlevel != max_level) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_maxlevel != max_level) {
 			/* bad maximum block map level */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCMXLVL);
 		}
-		for (agidx = 0; (agidx < MAXAG); agidx++) {	
+		for (agidx = 0; (agidx < MAXAG); agidx++) {
 			/* check out the active AGs */
 			if (bmap_recptr->AGActive[agidx]) {
 				highest_active_AG = agidx;
@@ -271,12 +274,12 @@ int ctlpage_verify(int8_t max_buddy)
 		 * bad block inode.  All we know for sure is that dn_maxag shouldn't
 		 * be larger than appropriate for the highest allocated block.
 		 */
-		if (bmap_recptr->bmpctl_bufptr->dn_maxag > highest_active_AG) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_maxag > highest_active_AG) {
 			/* bad highest active alloc group */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCMAAG);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agpref > highest_active_AG) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agpref > highest_active_AG) {
 			/* bad preferred alloc group */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCPAG);
@@ -293,45 +296,45 @@ int ctlpage_verify(int8_t max_buddy)
 			n <<= 2;
 		}		/* end for index */
 
-		if (bmap_recptr->bmpctl_bufptr->dn_aglevel != aglevel) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_aglevel != aglevel) {
 			/* bad level holding an AG */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCDMCLAG);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agheigth != agheight) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agheigth != agheight) {
 			/* bad dmapctl height holding an AG */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCDMCLH);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agwidth != agwidth) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agwidth != agwidth) {
 			/* bad width at level holding an AG */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCDMCLW);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agstart != agstart) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agstart != agstart) {
 			/* bad start idx at level holding an AG */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCDMCSTI);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agl2size != agg_recptr->log2_blksperag) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agl2size != agg_recptr->log2_blksperag) {
 			/* bad log2(fsblks per AG) */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCL2BPAG);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_agsize != sb_ptr->s_agsize) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_agsize != sb_ptr->s_agsize) {
 			/* bad fsblks per AG */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCBPAG);
 		}
-		if (bmap_recptr->bmpctl_bufptr->dn_maxfreebud != max_buddy) {	
+		if (bmap_recptr->bmpctl_bufptr->dn_maxfreebud != max_buddy) {
 			/* bad max free buddy system */
 			bmap_recptr->ctl_other_error = -1;
 			fsck_send_msg(fsck_BMAPCBMXB);
 		}
 		for (agidx = 0; (agidx < MAXAG); agidx++) {
 			/* verify the free list */
-			if (bmap_recptr->bmpctl_bufptr->dn_agfree[agidx] != 
-			    bmap_recptr->AGFree_tbl[agidx]) {	
+			if (bmap_recptr->bmpctl_bufptr->dn_agfree[agidx] !=
+			    bmap_recptr->AGFree_tbl[agidx]) {
 				/* bad free blocks in the AG */
 				bmap_recptr->ctl_fctl_error = -1;
 				fsck_send_msg(fsck_BMAPCAGNF, agidx);
@@ -390,11 +393,11 @@ int dmap_pwmap_rebuild(uint32_t * pmap_freeblks)
 
 			bmap_recptr->dmap_bufptr->wmap[map_wordidx] =
 			    wsp_bits[map_wordidx];
-			/*    
-			 * copy the word from workspace to buffer, 
+			/*
+			 * copy the word from workspace to buffer,
 			 * into both the working map and the permanent map.
 			 */
-			bmap_recptr->dmap_bufptr->pmap[map_wordidx] = 
+			bmap_recptr->dmap_bufptr->pmap[map_wordidx] =
 			    wsp_bits[map_wordidx];
 			/*
 			 * count the free blocks described by the word
@@ -407,7 +410,7 @@ int dmap_pwmap_rebuild(uint32_t * pmap_freeblks)
 					/* it's free */
 					(*pmap_freeblks)++;
 					agg_recptr->free_blocks_in_aggregate++;
-				} else {	
+				} else {
 					/* it's allocated */
 					agg_recptr->blocks_used_in_aggregate++;
 				}	/* end else it's allocated */
@@ -470,7 +473,7 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 
 	if (bdpv_rc != FSCK_OK)
 		goto bdpv_exit;
-		
+
 	for (map_wordidx = 0; (map_wordidx < LPERDMAP); map_wordidx++) {
 		max_buddy = ujfs_maxbuddy((char *) &(wsp_bits[map_wordidx]));
 		bmap_recptr->dmap_wsp_sleafs[map_wordidx] = max_buddy;
@@ -479,7 +482,7 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 			if (wsp_bits[map_wordidx] & bitmask) {
 				agg_recptr->blocks_used_in_aggregate++;
 				if (!(bmap_recptr->dmap_bufptr->
-				      pmap[map_wordidx] & bitmask)) {	
+				      pmap[map_wordidx] & bitmask)) {
 					/* pmap says not */
 					bmap_recptr->dmap_pmap_error = -1;
 					if (size_of_unmarked_range == 0) {
@@ -499,13 +502,13 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 						unmarked_range_bitidx =
 						    word_bitidx;
 						size_of_unmarked_range = 1;
-					} else {	
+					} else {
 						/* not the first in the range */
 						size_of_unmarked_range++;
 					}
-				} else {	
+				} else {
 					/* pmap agrees */
-					if (size_of_marked_range != 0) {	
+					if (size_of_marked_range != 0) {
 						/* marked range ended */
 						fsck_send_msg(fsck_PMAPSBOFF,
 							      (long long) size_of_marked_range,
@@ -514,7 +517,7 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 							      marked_range_bitidx);
 						size_of_marked_range = 0;
 					}
-					if (size_of_unmarked_range != 0) {	
+					if (size_of_unmarked_range != 0) {
 						/* unmarked range ended */
 						fsck_send_msg(fsck_PMAPSBON,
 							      (long long) size_of_unmarked_range,
@@ -524,12 +527,12 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 						size_of_unmarked_range = 0;
 					}
 				}
-			} else {	
+			} else {
 				/* fsck says not allocated */
 				(*pmap_freeblks)++;
 				agg_recptr->free_blocks_in_aggregate++;
-				if ((bmap_recptr->dmap_bufptr->pmap[map_wordidx] 
-				    & bitmask)) {	
+				if ((bmap_recptr->dmap_bufptr->pmap[map_wordidx]
+				    & bitmask)) {
 					/* pmap says yes */
 					bmap_recptr->dmap_pmap_error = -1;
 					if (size_of_marked_range == 0) {
@@ -550,11 +553,11 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 						marked_range_bitidx =
 						    word_bitidx;
 						size_of_marked_range = 1;
-					} else {	
+					} else {
 						/* not the first in the range */
 						size_of_marked_range++;
 					}
-				} else {	
+				} else {
 					/* pmap agrees */
 					if (size_of_marked_range != 0) {
 						fsck_send_msg(fsck_PMAPSBOFF,
@@ -579,7 +582,7 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 			bitmask = bitmask >> 1;
 		}
 	}
-	if (size_of_marked_range != 0) {	
+	if (size_of_marked_range != 0) {
 		/* marked range ended */
 		fsck_send_msg(fsck_PMAPSBOFF,(long long)size_of_marked_range,
 			      marked_range_first_ordno,marked_range_wordidx,
@@ -593,7 +596,7 @@ int dmap_pmap_verify(uint32_t * pmap_freeblks)
 			      unmarked_range_bitidx);
 		size_of_unmarked_range = 0;
 	}
-      bdpv_exit:        
+      bdpv_exit:
 	return (bdpv_rc);
 }
 
@@ -661,7 +664,7 @@ int dmap_tree_verify(int8_t * root_data)
 
 	prms_ptr->buf_tree = (dmtree_t *) & (bmap_recptr->dmap_bufptr->tree);
 
-	if (prms_ptr->buf_tree->dmt_nleafs != LPERDMAP) {	
+	if (prms_ptr->buf_tree->dmt_nleafs != LPERDMAP) {
 		/* wrong number of leafs */
 		bmap_recptr->dmap_other_error = -1;
 		tree_spec_errors = -1;
@@ -685,7 +688,7 @@ int dmap_tree_verify(int8_t * root_data)
 		tree_spec_errors = -1;
 		fsck_send_msg(fsck_BMAPBADHT, fsck_ref_msg(fsck_dmap), bmap_recptr->dmappg_ordno);
 	}
-	if (prms_ptr->buf_tree->dmt_budmin != BUDMIN) {	
+	if (prms_ptr->buf_tree->dmt_budmin != BUDMIN) {
 		/* wrong min buddy value */
 		bmap_recptr->dmap_other_error = -1;
 		tree_spec_errors = -1;
@@ -754,15 +757,15 @@ int dmappg_rebuild(int8_t * stree_root_data)
 		bmap_recptr->dmap_bufptr->nblocks = nblocks;
 		bdmpr_rc = dmap_pwmap_rebuild(&dmap_freeblks);
 		/*
-		 * subtract out any blocks which don't really exist but are 
-		 * described by a dmap (phantom blocks always appear to be in use) 
+		 * subtract out any blocks which don't really exist but are
+		 * described by a dmap (phantom blocks always appear to be in use)
 		 */
-		agg_recptr->blocks_used_in_aggregate = 
+		agg_recptr->blocks_used_in_aggregate =
 		    agg_recptr->blocks_used_in_aggregate - (BPERDMAP - nblocks);
 		if (bdmpr_rc == FSCK_OK) {
 			/* nothing strange during pmap rebld */
 			bmap_recptr->free_blocks += dmap_freeblks;
-			ag_num = bmap_recptr->dmap_1stblk >> 
+			ag_num = bmap_recptr->dmap_1stblk >>
 			    agg_recptr->log2_blksperag;
 			bmap_recptr->AGFree_tbl[ag_num] += dmap_freeblks;
 
@@ -814,9 +817,9 @@ int dmappg_verify(int8_t * stree_root_data)
 	    blktbl_dmap_get(bmap_recptr->dmap_1stblk,
 			    &(bmap_recptr->dmap_bufptr));
 
-	if (bdmpv_rc == FSCK_OK) {	
+	if (bdmpv_rc == FSCK_OK) {
 		/* the page is in the buffer */
-		if (bmap_recptr->dmap_bufptr->start != 
+		if (bmap_recptr->dmap_bufptr->start !=
 		    bmap_recptr->dmap_1stblk) {
 			/* bad starting block */
 			bmap_recptr->dmap_other_error = -1;
@@ -832,15 +835,15 @@ int dmappg_verify(int8_t * stree_root_data)
 		}
 		bdmpv_rc = dmap_pmap_verify(&dmap_freeblks);
 		/*
-		 * subtract out any blocks which don't really exist but are 
+		 * subtract out any blocks which don't really exist but are
 		 * described by a dmap (phantom blocks always appear to be in use)
 		 */
-		agg_recptr->blocks_used_in_aggregate = 
+		agg_recptr->blocks_used_in_aggregate =
 		    agg_recptr->blocks_used_in_aggregate - (BPERDMAP - nblocks);
 		if (bdmpv_rc == FSCK_OK) {
 			/* nothing strange during pmap ver */
 			bmap_recptr->free_blocks += dmap_freeblks;
-			ag_num = bmap_recptr->dmap_1stblk >> 
+			ag_num = bmap_recptr->dmap_1stblk >>
 			    agg_recptr->log2_blksperag;
 			bmap_recptr->AGFree_tbl[ag_num] += dmap_freeblks;
 			if (dmap_freeblks != nblocks) {
@@ -1124,7 +1127,7 @@ int Ln_tree_verify(int level, int64_t first_blk, struct dmapctl **addr_buf_ptr,
 			fsck_send_msg(fsck_BMAPBADNLF, fsck_ref_msg(prms_ptr->page_level),
 				      prms_ptr->page_ordno);
 		}
-		if (prms_ptr->buf_tree->dmt_l2nleafs != L2LPERCTL) {	
+		if (prms_ptr->buf_tree->dmt_l2nleafs != L2LPERCTL) {
 			/* wrong log2(nleafs) */
 			*other_errors = -1;
 			tree_spec_errors = -1;
@@ -1214,7 +1217,7 @@ int rebuild_blkall_map()
 		rbam_rc = dmappg_rebuild(&sumtree_root_data);
 		if (rbam_rc != FSCK_OK)
 			continue;
-			
+
 		/*
 		 * the data in the dmap summary tree root goes into a leaf of
 		 * the current L0 page
@@ -1224,12 +1227,12 @@ int rebuild_blkall_map()
 		/* move to next dmap page */
 		bmap_recptr->dmappg_ordno++;
 		bmap_recptr->dmap_1stblk += BPERDMAP;
-		if (bmap_recptr->dmappg_idx < MAXIDX) {	
+		if (bmap_recptr->dmappg_idx < MAXIDX) {
 			/* still gathering info about this L0 page */
 			bmap_recptr->dmappg_idx++;
 			continue;
 		}
-		
+
 		/* we have all the info needed for the current L0 page */
 		bmap_recptr->dmappg_idx = 0;
 		rbam_rc =
@@ -1494,7 +1497,7 @@ int verify_blkall_map()
 		vbam_rc = dmappg_verify(&sumtree_root_data);
 		if (vbam_rc != FSCK_OK)
 			continue;
-			
+
 		/*
 		 * the data in the dmap summary tree root goes into a leaf of
 		 * the current L0 page
@@ -1507,7 +1510,7 @@ int verify_blkall_map()
                 if (bmap_recptr->dmappg_idx < MAXIDX) {
 			/* still gathering info about this L0 page */
 			bmap_recptr->dmappg_idx++;
-			continue;			
+			continue;
 		}
 		/* we have all the info needed for the current L0 page */
 		bmap_recptr->dmappg_idx = 0;
@@ -1517,7 +1520,7 @@ int verify_blkall_map()
 
 		if (vbam_rc != FSCK_OK)
 			continue;
-			
+
 		/*
 		 * the data in the L0 summary tree root goes into
 		 * a leaf of the current L1 page
