@@ -3,18 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <config.h>
 #include "xfsckint.h"
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -161,7 +162,7 @@ int adjust_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 		if (ino_recptr->parent_inonum != 0) {
 			if ((ino_recptr->parent_inonum != ROOT_I)
 			    || (!agg_recptr->rootdir_rebuilt)) {
-				/* either this parent isn't the root or 
+				/* either this parent isn't the root or
 				   else the root dir has not been rebuilt */
 				adjps_rc =
 				    adjust_parent(ino_idx, ino_recptr,
@@ -189,8 +190,8 @@ int adjust_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 			if ((this_ext->inonum == ROOT_I)
 			    && (agg_recptr->rootdir_rebuilt)) {
 				/*
-				 * This parent is the root and the root dir has 
-				 * been rebuilt.  This is equivalent to a parent 
+				 * This parent is the root and the root dir has
+				 * been rebuilt.  This is equivalent to a parent
 				 * marked for release.
 				 */
 				release_inode_extension(this_ext);
@@ -208,7 +209,7 @@ int adjust_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 				ino_recptr->unxpctd_prnts = 0;
 
 			} else {
-				/* either not keeping the 'primary' 
+				/* either not keeping the 'primary'
 				   or else this isn't it */
 				adjps_rc =
 				    adjust_parent(ino_idx, ino_recptr,
@@ -627,12 +628,12 @@ int check_link_counts()
 			if ((this_inorec->parent_inonum == ROOT_I)
 			    && (agg_recptr->rootdir_rebuilt)) {
 				/*
-				 * special case: if the parent is root and root was 
+				 * special case: if the parent is root and root was
 				 * rebuilt, then don't increment parent
 				 */
 				if (this_inorec->inonum == ROOT_I) {
 					/*
-					 * special case: if this IS the root, then it's 
+					 * special case: if this IS the root, then it's
 					 * link from itself to itself DOES count
 					 */
 					this_inorec->link_count++;
@@ -874,7 +875,7 @@ int reset_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 	} else {
 		/* not a dir with multiple parents */
 		/*
-		 * the 1st parent observed is in the inode record.  
+		 * the 1st parent observed is in the inode record.
 		 * Any others are in extension records.
 		 */
 		resps_rc = get_inorecptr(aggregate_inode, alloc_ifnull,
@@ -890,7 +891,7 @@ int reset_parents(struct fsck_inode_record *ino_recptr, uint32_t ino_idx)
 			if ((ino_recptr->parent_inonum == ROOT_I)
 			    && (agg_recptr->rootdir_rebuilt)) {
 				/*
-				 * special case: if the parent is root and root 
+				 * special case: if the parent is root and root
 				 * was rebuilt, then this is an orphan
 				 */
 				ino_recptr->parent_inonum = 0;
