@@ -3,18 +3,20 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <config.h>
+#include <string.h>
 /* defines and includes common among the fsck.jfs modules */
 #include "xfsckint.h"
 #include "jfs_byteorder.h"
@@ -745,7 +747,7 @@ int get_path(uint32_t inode_idx, uint32_t parent_inonum, char **addr_path_addr,
 		path_ptr--;
 		agg_recptr->path_buffer[path_idx] = agg_recptr->delim_char;
 		/*
-		 * assume that we'll find a parent dir for the 
+		 * assume that we'll find a parent dir for the
 		 * path segment just copied into the path buffer.
 		 */
 		if (this_parent_inonum == ROOT_I) {
@@ -815,7 +817,7 @@ int in_inode_data_check(struct fsck_inode_record *inorecptr,
 	struct dinode an_inode;
 
 	/*
-	 * if in-inode data (or description of data) overflows 
+	 * if in-inode data (or description of data) overflows
 	 * this then the EA can NOT be inline
 	 */
 	size16 = sizeof (an_inode.di_inlinedata);
@@ -1242,8 +1244,8 @@ int validate_ACL(struct dinode *inoptr, uint32_t inoidx,
 					   &recorded_length, &extent_is_valid,
 					   FSCK_RECORD_DUPCHECK);
 			/*
-			 * add the blocks in the ACL extent to the running 
-			 * totals for the fileset and inode, but not for 
+			 * add the blocks in the ACL extent to the running
+			 * totals for the fileset and inode, but not for
 			 * the object represented by the object.
 			 */
 			agg_recptr->blocks_this_fset += recorded_length;
@@ -1513,11 +1515,11 @@ int validate_dir_data(struct dinode *inoptr, uint32_t inoidx,
 
 	}
 
-	/* 
+	/*
 	 * Check an error bit to see if there was something
 	 * wrong but non-fatal with xTree_processing.  If
 	 * so, reset the bit to give dTree_processing a
-	 * clean slate to start with.  Set a flag to 
+	 * clean slate to start with.  Set a flag to
 	 * indicate that the directory index table is to be rebuilt.
 	 */
 	if (inorecptr->ignore_alloc_blks) {
@@ -1939,8 +1941,8 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 		vrfi_rc = validate_dir_data(inoptr, inoidx, inorecptr,
 					    ino_msg_info_ptr);
 	} else if (ISREG(inoptr->di_mode) || ISLNK(inoptr->di_mode)) {
-		/* 
-		 * validate the data, if any,  whether 
+		/*
+		 * validate the data, if any,  whether
 		 * inline, a single extent, or a B+ Tree
 		 */
 		vrfi_rc =
@@ -2009,7 +2011,7 @@ int validate_record_fileset_inode(uint32_t inonum, uint32_t inoidx,
 				 * not sparse and size is greater than max,
 				 * then object size (in bytes) is is wrong
 				 * - tree must be bad.
-				 */ 
+				 */
 #ifdef _JFS_DEBUG
 				printf
 				    ("inode: %ld (t)   min_size = %lld (t)   "
