@@ -3,59 +3,23 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 #ifndef H_XFSCK
 #define H_XFSCK
 
-/*
-   -------------------------- system includes  --------------------------
-*/
-
-#include <stdarg.h>
-#include <stddef.h>
-
-#ifndef _JFS_FSCKDIRE
-#include <stdio.h>
-#endif
-
-#include <string.h>
-#include <stdlib.h>
-
-/*
-   ---------------------------- JFS includes  ----------------------------
-*/
-
 #include "jfs_types.h"
-#include "jfs_dinode.h"
 #include "jfs_dmap.h"
-#include "jfs_filsys.h"
-#include "jfs_imap.h"
-#include "jfs_superblock.h"
-#include "fsck_base.h"
-#include "fsckcbbl.h"
-
-/*
- * jfs library routine includes
- */
-#include "libjufs.h"
-#include "devices.h"
-#include "diskmap.h"
-#include "inode.h"
-#include "logform.h"
-#include "logredo.h"
-#include "message.h"
-#include "super.h"
 
 /* Stuff for handling extended attributes. */
 #ifndef OS2
@@ -146,9 +110,6 @@ extern int jfs_ValidateFEAList(struct FEALIST *, int, unsigned long *);
     * The following are used for reporting storage allocation
     * failures.
   */
-
-#ifndef _JFS_FSCKDIRE
-
 void report_dynstg_error(void);
 
 #define  dynstg_unknown          0
@@ -196,8 +157,6 @@ void report_dynstg_error(void);
 #define dynstg_fsit_inotbl      33
 #define dynstg_ait_inotbl       34
 
-#endif				/* ! _JFS_FSCKDIRE */
-
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
  * used during blockmap verify/rebuild
@@ -328,7 +287,7 @@ struct fsck_imap_msg_info {
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
- * The following define exit codes passed back by fsck.jfs 
+ * The following define exit codes passed back by fsck.jfs
  * and return codes passed internally in fsck.jfs.
  *
  */
