@@ -3,16 +3,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 /*
@@ -20,7 +20,7 @@
  *
  *      This tool extracts the contents of the specified (or implied)
  *      fsck service log on the specified device.  The output is
- *      written to a file (name specified or defaulted).  
+ *      written to a file (name specified or defaulted).
  *
  *      This routine also displays the contents of an extracted
  *      fsck service log.  If no input file name is specified,
@@ -42,12 +42,12 @@
  *                o -V prints the verstion number and date, and exits
  *
  *      SAMPLE INVOCATIONS:
- *         To extract the most recent log on /dev/hda5 into <pwd>fscklog.new         
+ *         To extract the most recent log on /dev/hda5 into <pwd>fscklog.new
  *                     jfs_fscklog -e /dev/hda5
  *
  *         To extract the most recent log on /dev/hda7 into <pwd>output.fil
  *                     jfs_fscklog -e /dev/hda7 -f output.fil
- * 
+ *
  *         To extract and display the most recent log on /dev/hdb3
  *                     jfs_fscklog -e /dev/hdb3 -d
  *
@@ -61,16 +61,20 @@
  *                     jfs_fscklog  -d -f input.fil
  *
  */
-#include "stdio.h"
-#include "stdlib.h"
+#define _GNU_SOURCE	/* for basename() */
+#include <config.h>
+#include <stdio.h>
+#include <stdlib.h>
 
 #include <string.h>
+#include <stdarg.h>
 #include <stdlib.h>
 #include <unistd.h>
 
-#include "config.h"
 #include "jfs_version.h"
 #include "jfs_fscklog.h"
+#include "xfsck.h"
+#include "fsck_message.h"
 
 struct fscklog_record fscklog_record;
 struct fscklog_record *local_recptr;
@@ -91,7 +95,7 @@ int v_send_msg(int, const char *, int, ...);
 
 /* VVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVVV */
 
-void fscklog_usage()
+void fscklog_usage(void)
 {
 	printf("\nUsage:  jfs_fscklog [-d] [-e device] [-f file.name] [-p] [-V]\n");
 	printf("\nEmergency help:\n"
@@ -215,7 +219,7 @@ int parse_parms(int argc, char **argv)
 			return (XCHKDMP_FAILED);
 		}
 	}
-	
+
 	if (argc < 2) {
 		fscklog_usage();
 		return (XCHKDMP_FAILED);
@@ -246,7 +250,7 @@ int v_send_msg(int msg_num, const char *file_name, int line_number, ...) {
 	vsnprintf(msg_string, sizeof(msg_string), message->msg_txt, args);
 	va_end(args);
 
-	sprintf(debug_detail, " [%s:%d]\n", file_name, line_number);
+	sprintf(debug_detail, " [%s:%d]\n", basename(file_name), line_number);
 
 	printf(msg_string);
 	printf(debug_detail);
