@@ -3,26 +3,20 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "jfs_types.h"
-
-/*
- * includes from JFS fsck
- */
-#include "fsck_message.h"
-#include "xfsck.h"
+#include "fscklog.h"
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
@@ -72,3 +66,6 @@ struct fscklog_record {
 #define XCHKDMP_MTORBADREAD        -3
 #define XCHKDMP_BADFORMAT          -4
 #define XCHKLOG_CANTOPENOUTFILE    -5
+
+extern int xchklog(struct fscklog_record *local_recptr);
+extern int xchkdmp(struct fscklog_record *local_recptr);
