@@ -3,18 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <config.h>
 #include "jfs_types.h"
 #include "jfs_dmap.h"
 #include "diskmap.h"
@@ -49,10 +50,10 @@ static int8_t budtab[256] = {
 
 /*
  * NAME: ujfs_maxbuddy
- *                                                                    
+ *
  * FUNCTION: Determines the maximum string of free blocks within a word of the
  *	wmap or pmap consistent with binary buddy.
- *                                                                    
+ *
  * PRE CONDITIONS:
  *
  * POST CONDITIONS:
@@ -94,9 +95,9 @@ int8_t ujfs_maxbuddy(unsigned char *cp)
 
 /*
  * NAME: ujfs_adjtree
- *                                                                    
+ *
  * FUNCTION: Calculate the tree of a dmap or dmapctl.
- *                                                                    
+ *
  * PRE CONDITIONS:
  *
  * POST CONDITIONS:
@@ -183,9 +184,9 @@ int8_t ujfs_adjtree(int8_t * treep, int32_t l2leaves, int32_t l2min)
 
 /*
  * NAME: ujfs_complete_dmap
- *                                                                    
+ *
  * FUNCTION: Fill in rest of dmap fields from wmap/pmap already initialized.
- *                                                                    
+ *
  * PARAMETERS:
  *	dmap_page	- dmap to complete
  *	blkno		- starting block number for this dmap
@@ -230,9 +231,9 @@ void ujfs_complete_dmap(struct dmap *dmap_page, int64_t blkno, int8_t *treemax)
 
 /*
  * NAME: ujfs_idmap_page
- *                                                                    
+ *
  * FUNCTION: Initialize one dmap page
- *                                                                    
+ *
  * POST CONDITIONS: Blocks which don't actually exist in the aggregate will be
  *	marked as allocated in the dmap page.  The total number of blocks will
  *	only account for the actually existing blocks.
@@ -278,9 +279,9 @@ void ujfs_idmap_page(struct dmap *map_page, uint32_t nblocks)
 
 /*
  * NAME: ujfs_getagl2size
- *                                                                    
+ *
  * FUNCTION: Determine log2(allocation group size) based on size of aggregate
- *                                                                    
+ *
  * PARAMETERS:
  *	size		- Number of blocks in aggregate
  *	aggr_block_size	- Aggregate block size
