@@ -36,6 +36,19 @@
 #include <sys/mount.h>
 #endif
 
+#if HAVE_SYS_STATVFS_H
+
+#include <sys/statvfs.h>
+#define STATFS statvfs
+#define NOWAIT ST_NOWAIT
+
+#else
+
+#define STATFS statfs
+#define NOWAIT MNT_NOWAIT
+
+#endif
+
 #include "devices.h"
 #include "message.h"
 
@@ -59,7 +72,7 @@ int Is_Root_Mounted_RO()
 
 #define TEST_FILE "/.ismount-test-file"
 
-	fd = open(TEST_FILE, O_RDWR | O_CREAT);
+	fd = open(TEST_FILE, O_RDWR | O_CREAT, S_IRWXU);
 
 	if (fd < 0) {
 		if (errno == EROFS)
@@ -254,11 +267,11 @@ int Is_Device_Type_JFS(char *Device_Name)
  */
 int Is_Device_Mounted(char *Device_Name)
 {
-	struct statfs *mp;
+	struct STATFS *mp;
 	int len, n;
 	char *s1, *s2;
 
-	n = getmntinfo(&mp, MNT_NOWAIT);
+	n = getmntinfo(&mp, NOWAIT);
 	if (!n)
 		return MSG_JFS_MNT_LIST_ERROR;
 
@@ -307,11 +320,11 @@ int Is_Device_Mounted(char *Device_Name)
  */
 int Is_Device_Type_JFS(char *Device_Name)
 {
-	struct statfs *mp;
+	struct STATFS *mp;
 	int len, n;
 	char *s1, *s2;
 
-	n = getmntinfo(&mp, MNT_NOWAIT);
+	n = getmntinfo(&mp, NOWAIT);
 	if (!n)
 		return MSG_JFS_MNT_LIST_ERROR;
 
