@@ -474,8 +474,9 @@ int moveWords(int32_t nwords,	/* number of 4-byte words to move */
 	 * get the previous page
 	 */
 
-	if (words != nwords	/* we get less than nwords */
-	    || j < 0) {		/* or exhaust the page, so offset is just */
+	while (words != nwords	/* we get less than nwords */
+	       || j < 0) {	/* or exhaust the page, so offset is just */
+		nwords -= words;
 		/* the page head, then j < 0              */
 		/* get previous page */
 		pno = logptr[*buf];
@@ -493,14 +494,16 @@ int moveWords(int32_t nwords,	/* number of 4-byte words to move */
 		*offset = LOGPSIZE - LOGPTLRSIZE;
 		/* index last word of data area */
 		j = LOGPSIZE / 4 - 4 - 1;
-		/* move rest of nwords if any. this will never
-		   exhaust the page.                          */
-		for (n = 0; n < nwords - words; n++) {
+		/* move rest of nwords if any. */
+		for (n = 0; n < nwords; n++) {
+			if (j < 0)
+				break;
 			*ptr = logp[*buf].data[j];
 			j = j - 1;
 			ptr = ptr - 1;
 		}
-		*offset = *offset - 4 * (nwords - words);
+		words = n;
+		*offset = *offset - 4 * nwords;
 	}
 
 	return (0);
