@@ -3,19 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "jfs_types.h"
+#include <config.h>
 #include <time.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -26,6 +26,8 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <assert.h>
+
+#include "jfs_types.h"
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -40,7 +42,6 @@
 #include "devices.h"
 #include "debug.h"
 #include "utilsubs.h"
-
 #include "fsck_message.h"		/* for chkdsk message logging facility */
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -218,7 +219,7 @@ int32_t dflag = 0;
  * FUNCTION:	Replay all transactions committed since the most
  *		recent synch point.
  *
- * NOTES:	
+ * NOTES:
  *	>>>>>> 	The log replay is accomplished in one pass over the
  *		log, reading backwards from logend to the first synch
  *		point record encountered.  This means that the log
@@ -388,7 +389,7 @@ int32_t dflag = 0;
  * name, get the log minor number for this filesystem. If it is a log name,
  * get its minor number.
  *
- * XJFS decided to put log inside the file system  
+ * XJFS decided to put log inside the file system
  *
  * For supporting the inline log, the above AIX logic should be changed.
  *
