@@ -23,7 +23,7 @@
 #define BADBLOCK	0x4
 
 int calc_map_size(int64_t, struct dinode *, int, int *, unsigned);
-int markit(int, unsigned);
+int markit(int64_t, unsigned);
 int record_LVM_BadBlks( int, int, int, struct dinode *, int64_t );
 int verify_last_blocks( FILE *, int, struct dinode * );
 int write_block_map(FILE *, int64_t, int);
