@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) International Business Machines Corp., 2000-2005
+ *   Copyright (C) International Business Machines Corp., 2000-2009
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -61,7 +61,6 @@ char msgstr[MAXSTR];
 
 #define L2MEGABYTE      20
 #define MEGABYTE        (1 << L2MEGABYTE)
-#define MEGABYTE32     (MEGABYTE << 5)
 #define MAX_LOG_PERCENTAGE  10	/* Log can be at most 10% of disk */
 #define create_journal_only  1
 #define use_existing_journal 2
@@ -217,7 +216,7 @@ static int create_aggregate(FILE *dev_ptr,
 	int64_t secondary_ait_address, secondary_aimap_address;
 	int64_t secondary_ait_end;
 	int64_t fsck_wspace_address, num_bits;
-	int fsck_wspace_length, fsck_svclog_length, npages;
+	int64_t fsck_wspace_length, fsck_svclog_length, npages;
 	unsigned inostamp;
 	struct dinode fileset_inode;
 
@@ -1023,9 +1022,13 @@ format_journal:
 			/* round up to meg */
 			logsize_in_bytes =
 			    (logsize_in_bytes + MEGABYTE - 1) & ~(MEGABYTE - 1);
-			if (logsize_in_bytes > MEGABYTE32) {
-				logsize_in_bytes = MEGABYTE32;
-			}
+			/*
+			 * jfs_logform enforces a 128 megabyte limit on an
+			 * external journal.  Assuming that's reasonable,
+			 * let's do the same for the internal journal.
+			 */
+			if (logsize_in_bytes > 128 * MEGABYTE)
+				logsize_in_bytes = 128 * MEGABYTE;
 		}
 
 		/* Convert logsize into aggregate blocks */
