@@ -3,35 +3,34 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 /*
  *   FUNCTION: Display and Alter structures in an unmounted filesystem
  */
-#include "config.h"
-
+#include <config.h>
 #include <fcntl.h>
+#include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 
 #include "xpeek.h"
 #include "jfs_endian.h"
 #include "jfs_logmgr.h"
 #include "jfs_version.h"
-
-/* libfs includes       */
-#include <devices.h>
-#include <inode.h>
-#include <super.h>
+#include "devices.h"
+#include "inode.h"
+#include "super.h"
 
 extern void superblock2(void);
 
