@@ -3,34 +3,26 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 /*
  *   FUNCTION: common data & function prototypes
  */
-#include <jfs_types.h>
-
-/* system includes */
 #include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
-#include <errno.h>
-
-/* JFS includes */
-#include <jfs_dinode.h>
-#include <jfs_imap.h>
-#include <jfs_superblock.h>
-#include <devices.h>
+#include "jfs_types.h"
+#include "jfs_dinode.h"
+#include "jfs_imap.h"
+#include "jfs_superblock.h"
 
 /* Defines */
 #define AGGREGATE_2ND_I -1
